GetIntegerCatFeatureHash

Function GetIntegerCatFeatureHash 

pub unsafe extern "C" fn GetIntegerCatFeatureHash(
    val: c_longlong,
) -> c_int
Special case for hash calculation - integer hash. Internally we cast value to string and then calulcate string hash function. Used in ClickHouse for catboost model evaluation on integer cat features. @param val integer cat feature value @return hash value